.. _dependencies:

============
Dependencies
============

Depends on a few standard libraries: python_ (the core language), numpy_ (for
numerical computation), scipy_ (for more specific mathematical operations),
cython_ (for extra speed) and nibabel_ (for file formats). Optionally, it can
use python-vtk_ (for visualisation), pytables_ (for handling large datasets),
matplotlib_ (for scientific plotting), and ipython_ (for interaction with the
code and its results).

.. include:: links_names.inc
